@@ -1,5 +1,7 @@
+import asyncio
 import logging
 import socket
+import threading
 import time
 import traceback
 from threading import Lock
@@ -9,6 +11,8 @@ from common import websocket
 from common.logger_factory import LoggerFactory
 from common.nat_serialization import NatSerialization
 from common.pool import SelectPool
+from common.register_append_data import ResisterAppendData
+from common.speed_limit import SpeedLimiter
 from constant.message_type_constnat import MessageTypeConstant
 from constant.system_constant import SystemConstant
 from context.context_utils import ContextUtils
@@ -25,17 +29,22 @@ class TcpForwardClient:
         self.ws = ws
         self.lock = Lock()
 
-        self.socket_event_loop =  SelectPool()
+        self.socket_event_loop = SelectPool()
 
     def start_forward(self):
         self.socket_event_loop.is_running = True
         self.socket_event_loop.run()
 
-    def handle_message(self, each: socket.socket):
-        # time.time()
+    def handle_message(self, each: socket.socket, data: ResisterAppendData):
         uid = self.socket_to_uid[each]
+        if data.speed_limiter and data.speed_limiter.is_exceed()[0]:
+            if LoggerFactory.get_logger().isEnabledFor(logging.DEBUG):
+                LoggerFactory.get_logger().debug('over speed')
+            self.socket_event_loop.unregister_and_register_delay(each, data, 1)
         try:
-            recv = each.recv(SystemConstant.CHUNK_SIZE)
+            recv = each.recv(data.read_size)
+            if data.speed_limiter:
+                data.speed_limiter.add(len(recv))
         except OSError:
             return
         send_message: MessageEntity = {
@@ -57,7 +66,7 @@ class TcpForwardClient:
             except Exception:
                 LoggerFactory.get_logger().error(f'close error: {traceback.format_exc()}')
 
-    def create_socket(self, name: str, uid: bytes, ip_port: str):
+    def create_socket(self, name: str, uid: bytes, ip_port: str, speed_limiter: SpeedLimiter):
         if uid in self.uid_to_socket:
             return
         with self.lock:
@@ -75,7 +84,7 @@ class TcpForwardClient:
                 self.socket_to_uid[s] = uid
                 if LoggerFactory.get_logger().isEnabledFor(logging.DEBUG):
                     LoggerFactory.get_logger().debug(f'register socket {name}, {uid}')
-                self.socket_event_loop.register(s, self.handle_message)
+                self.socket_event_loop.register(s, ResisterAppendData(self.handle_message, speed_limiter))
                 if LoggerFactory.get_logger().isEnabledFor(logging.DEBUG):
                     LoggerFactory.get_logger().debug(f'register socket success {name}, {uid}')
             except Exception:
