@@ -16,6 +16,8 @@ import tornado
 from common.logger_factory import LoggerFactory
 from common.nat_serialization import NatSerialization
 from common.pool import SelectPool
+from common.register_append_data import ResisterAppendData
+from common.speed_limit import SpeedLimiter
 from constant.message_type_constnat import MessageTypeConstant
 from constant.system_constant import SystemConstant
 from context.context_utils import ContextUtils
@@ -27,12 +29,14 @@ class TcpForwardClient:
 
     def __init__(self,  loop, tornado_loop):
         self.socket_event_loop =  SelectPool()
-        self.uid_to_client: Dict[bytes, socket.socket] = dict()
-        self.client_to_uid: Dict[socket.socket, bytes] = dict()
-        self.uid_to_name_ip_port : Dict[bytes, Tuple[str, str]]  = dict()
+        self.uid_to_client: Dict[bytes, socket.socket] = dict()   # uid 对应的连接公网端口的客户端
+        self.client_to_uid: Dict[socket.socket, bytes] = dict()  # 连接公网端口的客户端 对应的uid
+        self.uid_to_name_ip_port : Dict[bytes, Tuple[str, str]]  = dict()  # uid 对应的内网ipport
+
+        self.uid_to_listen_socket_server: Dict[bytes, socket.socket]  = dict()  # uid对应的监听socket
 
-        self.uid_to_listen_socket_server: Dict[bytes, socket.socket]  = dict()
         self.listen_socket_server_to_name_ip_port: Dict[socket.socket, Tuple[str, str]]  = dict()
+
         self.listen_socket_server_to_handler: Dict[socket.socket, 'MyWebSocketaHandler']  = dict()
 
         self.listen_socket_server_to_uid_set: Dict[socket.socket, Set] = defaultdict(set)
@@ -51,10 +55,7 @@ class TcpForwardClient:
             Thread(target=cls._instance.socket_event_loop.run).start()
         return cls._instance
 
-    def register_client(self, s: socket.socket):
-        self.socket_event_loop.register(s, self.handle_message)
-
-    async def register_listen_server(self, s: socket.socket, name: str, ip_port: str, websocket_handler: 'MyWebSocketaHandler'):
+    async def register_listen_server(self, s: socket.socket, name: str, ip_port: str, websocket_handler: 'MyWebSocketaHandler', speed_limit_size: float):
         client_name = websocket_handler.client_name
         if client_name not in self.client_name_to_lock:
             self.client_name_to_lock[client_name] = AsyncioLock()
@@ -62,7 +63,8 @@ class TcpForwardClient:
             self.listen_socket_server_to_name_ip_port[s] = (name, ip_port)
             self.listen_socket_server_to_handler[s] = websocket_handler
             self.client_name_to_listen_socket_server[client_name].append(s)
-            self.socket_event_loop.register(s, self.start_accept)
+            append_data = ResisterAppendData(self.start_accept, SpeedLimiter(speed_limit_size) if speed_limit_size else None)
+            self.socket_event_loop.register(s, append_data)
 
     async def close_by_client_name(self, client_name: str):
         if client_name not in self.client_name_to_listen_socket_server:
@@ -107,11 +109,17 @@ class TcpForwardClient:
             self.client_name_to_lock.pop(client_name)
         # self.client_name_to_lock.o
 
-    def handle_message(self, each: socket.socket):
+    def handle_message(self, each: socket.socket,  data: ResisterAppendData):
         # 发送到websocket
         each: socket.socket
+        if data.speed_limiter and data.speed_limiter.is_exceed()[0]:
+            if LoggerFactory.get_logger().isEnabledFor(logging.DEBUG):
+                LoggerFactory.get_logger().debug('over speed')
+            self.socket_event_loop.unregister_and_register_delay(each, data, 1)
         try:
-            recv = each.recv(SystemConstant.CHUNK_SIZE)
+            recv = each.recv(data.read_size)
+            if data.speed_limiter:
+                data.speed_limiter.add(len(recv))
         except ConnectionResetError:
             recv = b''
         # client = self.uid_to_client[uid]
@@ -141,7 +149,7 @@ class TcpForwardClient:
         except Exception:
             LoggerFactory.get_logger().error(traceback.format_exc())
 
-    def start_accept(self, s: socket):
+    def start_accept(self, s: socket, register_append_data: ResisterAppendData):
         # LoggerFactory.get_logger().info(f'start accept {self.listen_port}')
         # self.socket_event_loop.is_running = True
         # Thread(target=self.socket_event_loop.run).start()
@@ -158,7 +166,6 @@ class TcpForwardClient:
         # 当前 服务端的client 也会对应服务端连接内网服务的一个 client
         uid = os.urandom(4)
         handler = self.listen_socket_server_to_handler[s]
-
         self.listen_socket_server_to_uid_set[s].add(uid)
         self.uid_to_client[uid] = client
         self.client_to_uid[client] = uid
@@ -166,7 +173,8 @@ class TcpForwardClient:
         name, ip_port = self.listen_socket_server_to_name_ip_port[s]
         self.uid_to_name_ip_port[uid] = (name, ip_port)
         Thread(target=self.request_to_connect, args=(uid, )).start()
-        self.register_client(client)
+        append_data = ResisterAppendData(self.handle_message, register_append_data.speed_limiter)
+        self.socket_event_loop.register(client, append_data)
 
     def request_to_connect(self, uid: bytes):
         """请求连接客户端"""
